# Copyright (C) 2015 Swift Navigation Inc.
# Contact: Mark Fine <mark@swiftnav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

import time

from sbp.client.drivers.pyserial_driver import PySerialDriver
from sbp.client.loggers.byte_logger     import ByteLogger
from sbp.client.handler                 import Handler

DEFAULT_SERIAL_PORT  = "/dev/ttyUSB0"
DEFAULT_SERIAL_BAUD  = 1000000
DEFAULT_LOG_FILENAME = time.strftime("sbp-%Y%m%d-%H%M%S.log")

def get_args():
  """
  Get and parse arguments.
  """
  import argparse
  parser = argparse.ArgumentParser(description="Swift Navigation SBP Bytes Example.")
  parser.add_argument("-s", "--serial-port",
                      default=[DEFAULT_SERIAL_PORT], nargs=1,
                      help="specify the serial port to use.")
  parser.add_argument("-b", "--baud",
                      default=[DEFAULT_SERIAL_BAUD], nargs=1,
                      help="specify the baud rate to use.")
  parser.add_argument("-f", "--filename",
                      default=[DEFAULT_LOG_FILENAME], nargs=1,
                      help="specify the filename to write to.")
  return parser.parse_args()

def main():
  args = get_args()

  with PySerialDriver(args.serial_port[0], args.baud[0]) as driver:
    with Handler(driver.read, driver.write) as link:
      with ByteLogger(args.filename[0]) as logger:
        link.add_callback(logger)
        link.start

        try:
          while True:
            time.sleep(0.1)
        except KeyboardInterrupt:
          pass

if __name__ == "__main__":
  main()



import pusher
import pusherclient
import time

from sbp.client.drivers.pyserial_driver import PySerialDriver
from sbp.client                         import Handler, Framer
from sbp.observation                    import *
from sbp.msg                            import SBP

DEFAULT_SERIAL_PORT = "/dev/ttyUSB0"
DEFAULT_SERIAL_BAUD = 1000000

OBS_MSG_LIST = [SBP_MSG_OBS, SBP_MSG_BASE_POS, SBP_MSG_OBS_DEP_A]

def get_args():
  """
  Get and parse arguments.
  """
  import argparse
  parser = argparse.ArgumentParser(description="Swift Navigation SBP Pusher Example.")
  parser.add_argument("-a", "--app",
                      default=[None], nargs=1,
                      help="pusher app.")
  parser.add_argument("-k", "--key",
                      default=[None], nargs=1,
                      help="pusher app key.")
  parser.add_argument("-s", "--secret",
                      default=[None], nargs=1,
                      help="pusher app secret.")
  parser.add_argument("-p", "--port",
                      default=[DEFAULT_SERIAL_PORT], nargs=1,
                      help="specify the serial port to use.")
  parser.add_argument("-b", "--baud",
                      default=[DEFAULT_SERIAL_BAUD], nargs=1,
                      help="specify the baud rate to use.")
  parser.add_argument("-r", "--rx-channel-event",
                      default=[None], nargs=1,
                      help="pusher receive channel event.")
  parser.add_argument("-t", "--tx-channel-event",
                      default=[None], nargs=1,
                      help="pusher transmit channel event.")
  return parser.parse_args()

def main():
  args = get_args()
  app = args.app[0]
  key = args.key[0]
  secret = args.secret[0]
  port = args.port[0]
  baud = args.baud[0]
  rx_channel, rx_event = args.rx_channel_event[0].split(':')
  tx_channel, tx_event = args.tx_channel_event[0].split(':')
  push = pusher.Pusher(app_id=app, key=key, secret=secret, ssl=True, port=443)
  push_client = pusherclient.Pusher(key, secret=secret)
  with PySerialDriver(port, baud) as driver:
    with Handler(Framer(driver.read, driver.write)) as handler:

      def push_it(sbp_msg):
        push.trigger(tx_channel, tx_event, sbp_msg.to_json_dict())

      def pull_it(data):
        handler(SBP.from_json(data))

      def connect_it(data):
        push_client.subscribe(rx_channel).bind(rx_event, pull_it)

      push_client.connection.bind('pusher:connection_established', connect_it)
      push_client.connect()

      try:
        for msg, metadata in handler.filter(OBS_MSG_LIST):
          push_it(msg)
      except KeyboardInterrupt:
        pass

if __name__ == "__main__":
  main()




# Copyright (C) 2015 Swift Navigation Inc.
# Contact: Fergus Noble <fergus@swiftnav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

"""
the :mod:`sbp.client.examples.tweet` module contains a basic example of
reading SBP messages from a serial port, decoding TWEET messages and pushing
them to the twitter API.
"""

from sbp.client.drivers.pyserial_driver import PySerialDriver
from sbp.client.handler import Handler, Framer
from sbp.logging import SBP_MSG_TWEET, MsgTweet

import time
import twitter

twit = None

def main():

  import argparse
  parser = argparse.ArgumentParser(description="Swift Navigation Tweetxample.")
  parser.add_argument("TOKEN")
  parser.add_argument("TOKEN_KEY")
  parser.add_argument("CON_SEC")
  parser.add_argument("CON_SEC_KEY")
  parser.add_argument("-p", "--port",
                      default=['/dev/ttyUSB0'], nargs=1,
                      help="specify the serial port to use.")
  args = parser.parse_args()

  my_auth = twitter.OAuth(args.TOKEN, args.TOKEN_KEY,
                          args.CON_SEC, args.CON_SEC_KEY)
  twit = twitter.Twitter(auth=my_auth)

  # Open a connection to Piksi using the default baud rate (1Mbaud)
  with PySerialDriver(args.port[0], baud=1000000) as driver:
    # Create a handler to connect our Piksi driver to our callbacks
    with Handler(driver.read, driver.write, verbose=True) as handler:
      try:
        for msg, metadata in handler.filter(SBP_MSG_TWEET):
          if twit is not None:
            twit.statuses.update(msg)
      except KeyboardInterrupt:
        pass

if __name__ == "__main__":
  main()




# Copyright (C) 2015 Swift Navigation Inc.
# Contact: Fergus Noble <fergus@swiftnav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

"""
the :mod:`sbp.client.examples.udp` module contains an example of reading SBP
messages from a serial port and sending them to a UDP socket.
"""

from sbp.client.drivers.pyserial_driver import PySerialDriver
from sbp.client import Handler, Framer
from sbp.client.loggers.udp_logger import UdpLogger

import struct
import time

DEFAULT_SERIAL_PORT = "/dev/ttyUSB0"
DEFAULT_SERIAL_BAUD = 1000000

DEFAULT_UDP_ADDRESS = "127.0.0.1"
DEFAULT_UDP_PORT    = 13320

DEFAULT_LOG_FILENAME = time.strftime("sbp-%Y%m%d-%H%M%S.log")

def get_args():
  """
  Get and parse arguments.
  """
  import argparse
  parser = argparse.ArgumentParser(description="Swift Navigation SBP Example.")
  parser.add_argument("-s", "--serial-port",
                      default=[DEFAULT_SERIAL_PORT], nargs=1,
                      help="specify the serial port to use.")
  parser.add_argument("-b", "--baud",
                      default=[DEFAULT_SERIAL_BAUD], nargs=1,
                      help="specify the baud rate to use.")
  parser.add_argument("-a", "--address",
                      default=[DEFAULT_UDP_ADDRESS], nargs=1,
                      help="specify the serial port to use.")
  parser.add_argument("-p", "--udp-port",
                      default=[DEFAULT_UDP_PORT], nargs=1,
                      help="specify the baud rate to use.")
  return parser.parse_args()

def main():
  args = get_args()
  address = args.address[0]
  udp_port = args.udp_port[0]

  with PySerialDriver(args.serial_port[0], args.baud[0]) as driver:
    with Handler(Framer(driver.read, driver.write)) as handler:
      with UdpLogger(address, udp_port) as udp:
        handler.add_callback(udp)

        try:
          while True:
            time.sleep(0.1)
        except KeyboardInterrupt:
          pass

if __name__ == "__main__":
  main()




# Copyright (C) 2015 Swift Navigation Inc.
# Contact: Fergus Noble <fergus@swiftnav.com>
#
# This source is subject to the license found in the file 'LICENSE' which must
# be be distributed together with this source. All other rights reserved.
#
# THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.

"""
the :mod:`sbp.client.examples.simple` module contains a basic example of
reading SBP messages from a serial port, decoding BASELINE_NED messages and
printing them out.
"""

from sbp.client.drivers.pyserial_driver import PySerialDriver
from sbp.client import Handler, Framer
from sbp.client.loggers.json_logger import JSONLogger
from sbp.navigation import SBP_MSG_BASELINE_NED, MsgBaselineNED
import argparse

def main():
  parser = argparse.ArgumentParser(description="Swift Navigation SBP Example.")
  parser.add_argument("-p", "--port",
                      default=['/dev/ttyUSB0'], nargs=1,
                      help="specify the serial port to use.")
  args = parser.parse_args()

  # Open a connection to Piksi using the default baud rate (1Mbaud)
  with PySerialDriver(args.port[0], baud=1000000) as driver:
    with Handler(Framer(driver.read, None, verbose=True)) as source:
      try:
        for msg, metadata in source.filter(SBP_MSG_BASELINE_NED):
          # Print out the N, E, D coordinates of the baseline
          print "%.4f,%.4f,%.4f" % (msg.n * 1e-3, msg.e * 1e-3, msg.d * 1e-3)
      except KeyboardInterrupt:
        pass

if __name__ == "__main__":
  main()

